### Description

A collective noun is a singular noun that refers to a group of something. Examples: a **family, clan,** or **tribe** is a group of people who are related to each other; a **flock** is a group of birds or sheep; a **fleet** is a group of ships; and an **army** is a group of soldiers.

Many collective nouns are used exclusively as a singular replacement for a group as in the examples above. Frequently in the Bible the name of an ancestor is used, through a process of metonymy, as a collective noun referencing the group of his descendants. In the Bible, sometimes the singular noun will take a singular verb form, other times it will take a plural verb form. This may depend on how the author is thinking about the group, or whether the action is being done as a group or as individuals.

### Reason This is a Translation Issue

There are several issues that require care when translating collective nouns. Further care is needed because the language you are translating into may not use collective nouns in the same way as the language you are translating from. Issues include:

1. The source language may have a collective noun for a group that the target language does not and vice-versa. You may have to translate a collective noun with a plural noun in your language, or you may need to translate a plural noun with a collective noun in your language.
2. Subject-verb agreement. Different languages or dialects may have different rules about using singular or plural verbs with collective nouns.
   Examples (from Wikipedia):  
   - a singular noun with a singular verb: The team *is* in the dressing room.
   - a singular noun with a plural verb which is correct in British, but not American, English: The team *are* fighting among themselves. The team *have* finished the project.
3. Pronoun agreement. Similar to the previous, care needs to be taken to use the correct pronoun plurality and possibly gender or noun class to agree with the number/gender/class of the noun used. See the biblical examples below.
4. Clarity of referent. Especially if there is a mismatch in your translation between the verb and noun or pronoun concerning any of the factors above, readers may be confused about who or what is being referenced. 

### Examples from the Bible

> And Joab and all the **army** which was with him arrived (2 Samuel 3:23a ULT)

The word in bold is written in singular form in both Hebrew and English, but it refers to a group of warriors that fight together.

> and though the **flock** is cut off from the fold and there are no cattle in the stalls. (Habakkuk 3:17b ULT)

The word in bold is singular and refers to a group of sheep.

> And he went out again beside the sea, and all the **crowd** was coming to him, and he was teaching **them**. (Mark 2:13 ULT)

Note in this example that the noun is singular but the pronoun is plural. This may or may not be allowed or natural in your language.

> Do not let **your heart** be troubled. **You** believe in God; believe also in me. (John 14:1 ULT)

In this verse, the words translated “your” and “you” are plural, referring to many people. The word “heart” is singular in form, but it refers to all of their hearts as a group.

> And he shall take the **hair** of the head of his separation. And he shall put **it** on the fire that is under the sacrifice of the peace offerings. (Num 6:18b ULT)

 The word **hair** is singular, but it refers to many hairs, not just one.

> And Pharaoh said, “Who is Yahweh that I should listen to his voice to let **Israel** go? I do not know Yahweh; and moreover, I will not let **Israel** go.” (Exodus 5:2 ULT)

Here, "Israel" is singular, but means “the Israelites” by metonymy.

### Translation Strategies

If your language has a collective (singular) noun that refers to the same group as referenced by the collective noun in the source text, then translate the word using that term. If not, here are some strategies to consider:

(1) Translate the collective noun with a plural noun.  
(2) Add a plural word to the collective noun so that you can use a plural verb and pronouns.   
(3) Use a phrase to describe the group that the collective noun references. A useful strategy here can be to use a general collective noun that refers to a group of people or things.   
(4) If your language uses a collective noun for something that is a plural noun in the source language, you can translate the plural noun as a collective noun and, if necessary, change the form of the verb and any pronouns so that they agree with the singular noun. 

### Examples of Translation Strategies Applied

(1) Translate the collective noun with a plural noun.

> And Pharaoh said, “Who is Yahweh that I should listen to his voice to let **Israel** go? I do not know Yahweh; and moreover, I will not let **Israel** go.” (Exodus 5:2 ULT)

And Pharaoh said, “Who is Yahweh that I should listen to his voice to let **the Israelites** go? I do not know Yahweh; and moreover, I will not let **the Israelites** go.”

> And he shall take the **hair** of the head of his separation. And he shall put **it** on the fire that is under the sacrifice of the peace offerings. (Num 6:18b ULT)

And he shall take the **hairs** of the head of his separation. And he shall put **them** on the fire that is under the sacrifice of the peace offerings.

(2) Add a plural word to the collective noun so that you can use a plural verb and pronouns.

> And Joab and all the **army** which was with him arrived (2 Samuel 3:23a ULT)

And Joab and all the **army men who were** with him arrived

> And he went out again beside the sea, and all the **crowd** was coming to him, and he was teaching **them**. (Mark 2:13 ULT)

And he went out again beside the sea, and all the **people of the crowd were** coming to him, and he was teaching **them**. 

(3) Use a phrase to describe the group that the collective noun references. A useful strategy here can be to use a general collective noun that refers to a group of people or things.

> and though the **flock** is cut off from the fold and there are no cattle in the stalls. (Habakkuk 3:17b ULT)

and though the **group of sheep** is cut off from the fold and there are no cattle in the stalls.

> And Pharaoh said, “Who is Yahweh that I should listen to his voice to let **Israel** go? I do not know Yahweh; and moreover, I will not let **Israel** go.” (Exodus 5:2 ULT)

And Pharaoh said, “Who is Yahweh that I should listen to his voice to let **the people of Israel** go? I do not know Yahweh; and moreover, I will not let **the people of Israel** go.” 

(4) If your language uses a collective noun for something that is a plural noun in the source language, you can translate the plural noun as a collective noun and, if necessary, change the form of the verb and any pronouns so that they agree with the singular noun.

> Now this John had his clothing from the **hairs** of a camel and a leather belt around his waist (Matthew 3:4a ULT)

Now this John had his clothing from the **hair** of a camel and a leather belt around his waist

> You shall not make for yourself a carved figure nor any likeness that {is} in **the heavens** above, or that {is} in the earth beneath, or that {is} in **the waters** under the earth. (Deuteronomy 5:8 ULT)

You shall not make for yourself a carved figure nor any likeness that is in **heaven** above, or that is in the earth beneath, or that is in **the water** under the earth. 
